package com.zhyc.module.app.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.zhyc.module.app.domain.AppSettings;
import com.zhyc.module.app.service.IAppSettingsService;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.zhyc.common.annotation.Log;
import com.zhyc.common.core.controller.BaseController;
import com.zhyc.common.core.domain.AjaxResult;
import com.zhyc.common.enums.BusinessType;

import com.zhyc.common.utils.poi.ExcelUtil;
import com.zhyc.common.core.page.TableDataInfo;

/**
 * 应用设置Controller
 * 
 * @author ruoyi
 * @date 2026-01-20
 */
@RestController
@RequestMapping("/app/settings")
public class AppSettingsController extends BaseController
{
    @Autowired
    private IAppSettingsService appSettingsService;

    /**
     * 查询应用设置列表
     */
//    @PreAuthorize("@ss.hasPermi('app:settings:list')")
    @GetMapping("/list")
    public TableDataInfo list(AppSettings appSettings)
    {
        startPage();
        List<AppSettings> list = appSettingsService.selectAppSettingsList(appSettings);
        return getDataTable(list);
    }

    /**
     * 导出应用设置列表
     */
//    @PreAuthorize("@ss.hasPermi('app:settings:export')")
    @Log(title = "应用设置", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, AppSettings appSettings)
    {
        List<AppSettings> list = appSettingsService.selectAppSettingsList(appSettings);
        ExcelUtil<AppSettings> util = new ExcelUtil<AppSettings>(AppSettings.class);
        util.exportExcel(response, list, "应用设置数据");
    }

    /**
     * 获取应用设置详细信息
     */
//    @PreAuthorize("@ss.hasPermi('app:settings:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(appSettingsService.selectAppSettingsById(id));
    }

    /**
     * 新增应用设置
     */
//    @PreAuthorize("@ss.hasPermi('app:settings:add')")
    @Log(title = "应用设置", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody AppSettings appSettings)
    {
        return toAjax(appSettingsService.insertAppSettings(appSettings));
    }

    /**
     * 修改应用设置
     */
//    @PreAuthorize("@ss.hasPermi('app:settings:edit')")
    @Log(title = "应用设置", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody AppSettings appSettings)
    {
        return toAjax(appSettingsService.updateAppSettings(appSettings));
    }

    /**
     * 删除应用设置
     */
//    @PreAuthorize("@ss.hasPermi('app:settings:remove')")
    @Log(title = "应用设置", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(appSettingsService.deleteAppSettingsByIds(ids));
    }
}
